use macro_rules_attribute::apply;

use crate::{
    macros::{
        ConfigFile,
        DefDer,
    },
    types::{
        self,
        dns::Dns,
        structs::DnsToken,
        traits::DnsHandler,
    },
};

#[apply(DefDer)]
#[apply(ConfigFile)]
#[serde(deny_unknown_fields)]
pub struct DNSUpdateClientOptions {}

impl DNSUpdateClientOptions {
    pub fn build(self, _zone: String) -> Dns {
        Dns::DNSUpdate(DnsUpdateHandler {})
    }
}

#[apply(DefDer)]
pub struct DnsUpdateHandler {}

impl DnsHandler for DnsUpdateHandler {
    async fn set_record(&self, _domain: String, _content: String) -> types::Result<DnsToken> {
        Ok(DnsToken::new_dns_update())
    }
}

#[apply(DefDer)]
pub struct DnsUpdateToken {}

impl DnsUpdateToken {
    pub async fn remove(&mut self) {}
}

unsafe impl Send for DnsUpdateToken {}
